@@ -4,6 +4,7 @@ from pathlib import Path
 from typing import Optional
 
 # external
+import attr
 import tomlkit
 from dephell_discover import Root as PackageRoot
 from dephell_specifier import RangeSpecifier
@@ -17,8 +18,9 @@ from .base import BaseConverter
 from .egginfo import EggInfoConverter
 
 
+@attr.s()
 class FlitConverter(BaseConverter):
-    lock = False
+    lock = attr.ib(type=bool, default=False)
 
     def can_parse(self, path: Path, content: Optional[str] = None) -> bool:
         if not content:
