@@ -1,10 +1,8 @@
 # built-in
 import re
 
-# external
-import requests
-
 # app
+from ...networking import requests_session
 from ..cached_property import cached_property
 from .base import BaseRepo
 
@@ -27,7 +25,8 @@ class GitHubRepo(BaseRepo):
             author=self.author,
             name=self.name,
         )
-        response = requests.get(url)
+        with requests_session() as session:
+            response = session.get(url)
 
         tags = []
         for release in response.json():
